@@ -4,9 +4,10 @@
 #' @param start start date to plot, if not specified, all date in ohlc will be included
 #' @param end end date to plot
 #' @param main an overall title for the plot
-#' @param ... Arguments to be passed to methods
+#' @param ... Arguments to be passed to ggplot
 #' @seealso \code{\link{get.ohlc.yahoo}}
 #' @seealso \code{\link{get.ohlc.google}}
+#' @importFrom ggplot2 ggplot geom_boxplot theme theme_bw scale_fill_manual labs aes_string element_text
 #' @export
 #' @examples
 #' # google <- get.ohlc.yahoo("GOOG",start="2013-07-01",end="2013-08-01"); candlestickChart(google)
@@ -22,8 +23,8 @@ candlestickChart <- function(ohlc, start=NULL, end=NULL, main="", ...){
   xSubset <-data.frame('date'=date,'open'=open,'high'= high,'low'=low,'close'=close)
    
   xSubset$candleLower <- pmin(xSubset$open, xSubset$close)
-  xSubset$candleMiddle <- NA
   xSubset$candleUpper <- pmax(xSubset$open, xSubset$close)
+  xSubset$candleMiddle = (xSubset$candleLower+xSubset$candleUpper)/2
   xSubset$fill <- 'red'
   xSubset$fill[xSubset$open < xSubset$close] = ''
   
@@ -32,11 +33,10 @@ candlestickChart <- function(ohlc, start=NULL, end=NULL, main="", ...){
     end=as.Date(end)
     xSubset <-subset(xSubset, xSubset$date > start & xSubset$date < end) 
   }
-  myBreak=date.breaks(xSubset)
-  g <- ggplot(xSubset, aes_string(x='date', lower='candleLower', middle='candleMiddle', upper='candleUpper', ymin='low', ymax='high',na.rm=TRUE)) +
-    geom_boxplot(stat='identity', aes_string(group='date', fill='fill')) + theme_bw() + 
-    scale_fill_manual(name = "", values = c("white", "red")) + labs( title =main ) + labs(x="") +
-    theme(legend.position="none") + theme(axis.text.x=element_text(angle=90)) +
-    scale_x_date(labels = date_format("%Y-%m-%d"),breaks=date_breaks(myBreak))
+
+  g <- ggplot(xSubset, aes_string(x='date', lower='candleLower', middle='candleMiddle', upper='candleUpper', ymin='low', ymax='high',na.rm=TRUE),...) +
+          geom_boxplot(stat='identity', aes_string(group='date', fill='fill')) + theme_bw() + 
+          scale_fill_manual(name = "", values = c("red", "green")) + labs( title =main ) + labs(x="") +
+          theme(legend.position="none") + theme(axis.text.x=element_text(angle=90))
   return(g)
 }
